@@ -28,3 +28,9 @@ void Options::on_clearButton_clicked()
     this->clearCurrentClicked();
     this->close();
 }
+
+void Options::on_removePlaylists_clicked()
+{
+    this->removePlaylistsButtonClicked();
+    this->close();
+}
