@@ -50,3 +50,25 @@ void Playlists::addNewItemToPlaylist(QString title, QString item)
         qDebug()<<"write error";
 
 }
+
+void Playlists::removePlaylistItem(QTreeWidgetItem *item, int column, QTreeWidgetItem *parent)
+{
+    QStringList items;
+    items = playlists.value(parent->text(column));
+    int i = 0;
+    foreach (QString playlistItem, items)
+    {
+        if (playlistItem == item->text(column))
+        {
+            items.removeAt(i);
+            break;
+        }
+        i ++;
+    }
+}
+
+void Playlists::removePlaylist(QString title)
+{
+    playlists.remove(title);
+
+}
